Copyright (C) 2017-2023 The Simons Foundation, Inc. - All Rights Reserved.

Lead developer: Alex H. Barnett; see docs/ackn.rst for other contributors.

---

FINUFFT is licensed under the Apache License, Version 2.0 (the "License"); you
may not use this file except in compliance with the License. You may obtain a
copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed
under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
CONDITIONS OF ANY KIND, either express or implied. See the License for the
specific language governing permissions and limitations under the License.

---

Certain parts of this repository are contributed by others. For their license
info, see:

contrib/legendre_rule_fast.license fortran/cmcl_license.txt
tutorial/utils/lgwt.m

---

If you find this library useful, or it helps you in creating software or
publications, please let us know, and acknowledge that fact by citing our
repository:

https://github.com/flatironinstitute/finufft

and the corresponding journal articles (particularly the first):

A parallel non-uniform fast Fourier transform library based on an ``exponential
of semicircle'' kernel. A. H. Barnett, J. F. Magland, and L. af Klinteberg. SIAM
J. Sci. Comput. 41(5), C479-C504 (2019).

Aliasing error of the exp$(\beta \sqrt{1-z^2})$ kernel in the nonuniform fast
Fourier transform. A. H. Barnett, Appl. Comput. Harmon. Anal. 51, 1-16 (2021).
